function esn = generate_esn_8(d, reservoirSize, p, varargin)
% generate an untrained "raw" ESN with p input neurons, p * d output
% neurons. Idea: p neurons code pitch, d is number of trained delays.

clear esn;

esn.reservoirSize = reservoirSize; esn.d = d; esn.p = p; 

% create internal weight matrix with spectral radius 1 and connectivity
% such that on average each unit is connected to 10 others
connectivity = min([10/reservoirSize 1]);
esn.W = generate_internal_weights(reservoirSize, connectivity);

% input weight matrix has weight vectors per input unit in colums
esn.W_in = 2.0 * rand(reservoirSize, p)- 1.0;

% initialize output weights
esn.W_out = zeros(p, reservoirSize + p, d);

%init default parameters
esn.spectralRadius = 0.8; 
esn.inputWeightScaling = ones(p,1);
esn.bias = zeros(p,1);
esn.teacherScaling = ones(p, d);
esn.teacherShift  = zeros(p, d);
esn.inputScaling = ones(p, 1);
esn.inputShift  = zeros(p, 1);
esn.noiseLevel = 0.0 ;
esn.reservoirActivationFunction = 'tanh';
esn.dataActivationFunction = 'sigmoid01' ; 
esn.inverseDataActivationFunction = 'sigmoid01_inv' ; 
esn.methodTrain = 'pseudoinverse_8' ; 

args = varargin; 
nargs= length(args);
for i = 1:2:nargs
  switch args{i},
   case 'spectralRadius', esn.spectralRadius = args{i+1} ;  
   case 'inputWeightScaling', esn.inputWeightScaling = args{i+1} ; 
   case 'bias', esn.bias = args{i+1} ; 
   case 'teacherScaling', esn.teacherScaling = args{i+1} ; 
   case 'teacherShift', esn.teacherShift = args{i+1} ;
   case 'inputScaling', esn.inputScaling = args{i+1} ; 
   case 'inputShift', esn.inputShift = args{i+1} ;
   case 'noiseLevel', esn.noiseLevel = args{i+1} ; 
   case 'reservoirActivationFunction', esn.reservoirActivationFunction = args{i+1};
   case 'dataActivationFunction', esn.dataActivationFunction = args{i+1};  
   case 'inverseDataActivationFunction', esn.inverseDataActivationFunction = args{i+1}; 
   case 'methodTrain', esn.methodTrain = args{i+1} ;       
   otherwise error('the option does not exist'); 
  end      
end







