function unitCodedSignal = rawToUnitCoded(rawSignal, nPitches)
% transforms a 1-d stretchedSignal rawSignal with range [0,1] into
% nPitches-dimensional signal
% (each dim ranging in [0,1]) through nPitches many triangular, equally
% spaced membership functions
%
% unitCodedSignal has size (length(rawSignal) , nPitches)

l = length(rawSignal);
unitCodedSignal = zeros(l, nPitches);
stretchedSignal = rawSignal * (nPitches - 1);

for i = 1:l
    for p = 1:nPitches
        unitCodedSignal(i, p) = unitTriangle(stretchedSignal(i,1) - p + 1);
    end    
end

function membershipValue = unitTriangle(x)
% computes the membership function of a unit triangle centered at zero
if abs(x) > 1
    membershipValue = 0;
else
    membershipValue = 1 - abs(x);
end